@@ -1,17 +1,15 @@
 import os
 import signal
 import sys
-
-from plumbum import colors
 from traceback import print_exc
 
+from plumbum import colors
 from PyQt5 import QtWidgets
-from pyqtgraph.Qt import QtCore, QtGui
-
+from pyqtgraph.Qt import QtCore
 
 # it may seem odd to include '.', but for some reason this is needed for
 # standalone windows executable
-sys.path += ['../', os.path.join('..', '..'), '.']
+sys.path += ["../", os.path.join("..", ".."), "."]
 
 import linien
 from linien.gui.widgets import CustomWidget, ui_path
@@ -20,6 +18,8 @@ sys.path += [ui_path]
 
 from linien.gui.ui.device_manager import DeviceManager
 from linien.gui.ui.main_window import MainWindow
+from linien.gui.ui.psd_window import PSDWindow
+from linien.gui.ui.version_checker import VersionCheckerThread
 from linien.gui.utils_gui import set_window_icon
 
 
@@ -37,38 +37,49 @@ class QTApp(QtCore.QObject):
         self.device_manager.app = self
         self.device_manager.show()
 
-        self.app.aboutToQuit.connect(lambda: self.app.quit())
+        self.psd_window = PSDWindow()
+        self.psd_window.app = self
 
+        self.app.aboutToQuit.connect(lambda: self.app.quit())
 
         super().__init__()
 
-    def connected(self, connection, parameters, control):
+    def client_connected(self, client):
         self.device_manager.hide()
-        self.main_window.show(connection.host, connection.device['name'])
+        self.main_window.show(client.host, client.device["name"])
 
-        self.connection = connection
-        self.control = control
-        self.parameters = parameters
+        self.client = client
+        self.control = client.control
+        self.parameters = client.parameters
 
         self.ready.connect(self.init)
         self.ready.emit(True)
 
     def init(self):
+
         for instance in CustomWidget.instances:
             try:
                 instance.connection_established()
-            except:
-                print('the error below happend when calling connection_established of a widget. This may happen if the widget was recently destroyed.')
+            except Exception:
+                print(
+                    (
+                        "The error below happend when calling connection_established "
+                        "of a widget. This may happen if the widget was recently "
+                        "destroyed."
+                    )
+                )
                 print_exc()
 
         self.call_listeners()
 
+        self.check_for_new_version()
+
     def call_listeners(self):
-        if hasattr(self, 'connection') and self.connection and self.connection.connected:
+        if hasattr(self, "client") and self.client and self.client.connected:
             try:
                 self.parameters.call_listeners()
-            except:
-                print(colors.red | 'call_listeners() failed')
+            except Exception:
+                print(colors.red | "call_listeners() failed")
                 print_exc()
 
             QtCore.QTimer.singleShot(50, self.call_listeners)
@@ -82,19 +93,41 @@ class QTApp(QtCore.QObject):
         self.app.quit()
 
     def shutdown(self):
-        self.control.shutdown()
+        self.client.control.shutdown()
         self.close()
 
+    def open_psd_window(self):
+        # first hiding it, then showing it brings it to foregroud if it is in
+        # background
+        self.psd_window.hide()
+        self.psd_window.show()
+
     def open_device_manager(self):
         self.main_window.hide()
         self.device_manager.show()
 
-        self.connection.disconnect()
-        del self.connection
+        self.client.disconnect()
+        del self.client
+
+    def close_all_secondary_windows(self):
+        self.psd_window.hide()
+
+    def check_for_new_version(self):
+        self.version_checker = VersionCheckerThread()
+        self.version_checker.check_done.connect(self.new_version_available)
+        self.version_checker.start()
+
+    def new_version_available(self, new_version_available):
+        if new_version_available:
+            print("new version available")
+            self.main_window.show_new_version_available()
+        else:
+            print("no new version available")
+            QtCore.QTimer.singleShot(1000 * 60 * 60, self.check_for_new_version)
 
 
 def run_application():
-    print('Linien spectroscopy lock version ' + (colors.bold | linien.__version__))
+    print("Linien spectroscopy lock version " + (colors.bold | linien.__version__))
     gui = QTApp()
 
     # catch ctrl-c and shutdown
@@ -102,5 +135,5 @@ def run_application():
     sys.exit(gui.app.exec_())
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     run_application()
